@@ -1,8 +1,10 @@
 /*
- * i-scream libstatgrab
- * http://www.i-scream.org
- * Copyright (C) 2000-2013 i-scream
- * Copyright (C) 2010-2013 Jens Rehsack
+ * libstatgrab
+ * https://libstatgrab.org
+ * Copyright (C) 2003-2004 Peter Saunders
+ * Copyright (C) 2003-2019 Tim Bishop
+ * Copyright (C) 2003-2013 Adam Sampson
+ * Copyright (C) 2012-2019 Jens Rehsack
  * 
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -18,8 +20,6 @@
  * License along with this library; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
  * 02110-1301, USA.
- *
- * $Id$
  */
 
 #ifdef _AIX
@@ -555,35 +555,28 @@ sg_get_network_io_stats_int(sg_vector **network_io_stats_vector_ptr){
 			network_io_ptr[interfaces].rx=knp->VALTYPE;
 
 			/* Read tx */
-			if((knp=kstat_data_lookup(ksp, LTX))==NULL)
-				continue;
-			network_io_ptr[interfaces].tx=knp->VALTYPE;
+			if((knp=kstat_data_lookup(ksp, LTX))!=NULL)
+				network_io_ptr[interfaces].tx=knp->VALTYPE;
 
 			/* Read ipackets */
-			if((knp=kstat_data_lookup(ksp, LIPACKETS))==NULL)
-				continue;
-			network_io_ptr[interfaces].ipackets=knp->VALTYPE;
+			if((knp=kstat_data_lookup(ksp, LIPACKETS))!=NULL)
+				network_io_ptr[interfaces].ipackets=knp->VALTYPE;
 
 			/* Read opackets */
-			if((knp=kstat_data_lookup(ksp, LOPACKETS))==NULL)
-				continue;
-			network_io_ptr[interfaces].opackets=knp->VALTYPE;
+			if((knp=kstat_data_lookup(ksp, LOPACKETS))!=NULL)
+				network_io_ptr[interfaces].opackets=knp->VALTYPE;
 
 			/* Read ierrors */
-			if((knp=kstat_data_lookup(ksp, "ierrors"))==NULL)
-				continue;
-			network_io_ptr[interfaces].ierrors=knp->value.ui32;
+			if((knp=kstat_data_lookup(ksp, "ierrors"))!=NULL)
+				network_io_ptr[interfaces].ierrors=knp->value.ui32;
 
 			/* Read oerrors */
-			if((knp=kstat_data_lookup(ksp, "oerrors"))==NULL)
-				continue;
-			network_io_ptr[interfaces].oerrors=knp->value.ui32;
+			if((knp=kstat_data_lookup(ksp, "oerrors"))!=NULL)
+				network_io_ptr[interfaces].oerrors=knp->value.ui32;
 
 			/* Read collisions */
-			if((knp=kstat_data_lookup(ksp, "collisions"))==NULL)
-				continue;
-			network_io_ptr[interfaces].collisions=knp->value.ui32;
-
+			if((knp=kstat_data_lookup(ksp, "collisions"))!=NULL)
+				network_io_ptr[interfaces].collisions=knp->value.ui32;
 
 			/* Store systime */
 			network_io_ptr[interfaces].systime=time(NULL);
@@ -605,6 +598,7 @@ sg_get_network_io_stats_int(sg_vector **network_io_stats_vector_ptr){
 	/* read the 2 lines.. Its the title, so we dont care :) */
 	if( ( NULL == fgets(line, sizeof(line), f) ) ||
 	    ( NULL == fgets(line, sizeof(line), f) ) ) {
+		fclose(f);
 		RETURN_WITH_SET_ERROR_WITH_ERRNO("network", SG_ERROR_PARSE, "/proc/net/dev");
 	}
 
@@ -1186,7 +1180,23 @@ skip:
 			}
 
 			if ((ifr.ifr_flags & IFF_UP) != 0) {
-				if ((knp = kstat_data_lookup(ksp, "link_up")) != NULL) {
+				/* module=ce,  instance=0, name=ce0,  class=net 
+				   module=hme, instance=0, name=hme0, class=net */
+				if ((knp = kstat_data_lookup(ksp, "link_up")) == NULL) {
+					/* module=bge, instance=0, name=mii, class=net */
+					kstat_t *mksp = kstat_lookup(kc,ksp->ks_module,ksp->ks_instance,"mii");
+					if (mksp != NULL) {
+						knp = kstat_data_lookup(mksp,"link_up");
+						if (knp == NULL) {
+							/* module=e1000g, instance=0, name=statistics, class=net */
+							mksp = kstat_lookup(kc,ksp->ks_module,ksp->ks_instance,"statistics");
+							if (mksp != NULL)
+								knp = kstat_data_lookup(mksp,"link_up");
+						}
+					}
+				}
+
+				if (knp != NULL) {
 					/* take in to account if link
 					 * is up as well as interface */
 					network_iface_stat[ifaces].up = (knp->value.ui32 != 0u) ? SG_IFACE_UP : SG_IFACE_DOWN;
