@@ -1,8 +1,10 @@
 /*
- * i-scream libstatgrab
- * http://www.i-scream.org
- * Copyright (C) 2000-2013 i-scream
- * Copyright (C) 2010-2013 Jens Rehsack
+ * libstatgrab
+ * https://libstatgrab.org
+ * Copyright (C) 2003-2004 Peter Saunders
+ * Copyright (C) 2003-2019 Tim Bishop
+ * Copyright (C) 2003-2013 Adam Sampson
+ * Copyright (C) 2012-2019 Jens Rehsack
  * 
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -18,8 +20,6 @@
  * License along with this library; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
  * 02110-1301, USA.
- *
- * $Id$
  */
 
 #ifndef STATGRAB_TOOLS_H
@@ -438,6 +438,9 @@ extern "C" strcasecmp(const char *s1, const char *s2);
 #ifdef HAVE_KINFO_H
 # include <kinfo.h>
 #endif
+#ifdef HAVE_LIBPROC_H
+# include <libproc.h>
+#endif
 #ifdef HAVE_SYS_SYSTEMINFO_H
 # include <sys/systeminfo.h>
 #endif
