@@ -1,8 +1,10 @@
 /*
- * i-scream libstatgrab
- * http://www.i-scream.org
- * Copyright (C) 2000-2013 i-scream
- * Copyright (C) 2010-2013 Jens Rehsack
+ * libstatgrab
+ * https://libstatgrab.org
+ * Copyright (C) 2003-2004 Peter Saunders
+ * Copyright (C) 2003-2019 Tim Bishop
+ * Copyright (C) 2003-2013 Adam Sampson
+ * Copyright (C) 2012-2019 Jens Rehsack
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -18,8 +20,6 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
  * 02110-1301, USA.
- *
- * $Id$
  */
 
 #ifdef HAVE_CONFIG_H
@@ -45,6 +45,10 @@
 #include <sys/termios.h>
 #endif
 
+#if defined(WITH_LIBLOG4CPLUS)
+#include <log4cplus/clogger.h>
+#endif
+
 #ifdef HAVE_NCURSES_H
 #define COLOR_SUPPORT
 #endif
@@ -792,6 +796,16 @@ set_valid_filesystems(char const *fslist) {
 	return SG_ERROR_NONE;
 }
 
+#ifdef HAVE_LOG4CPLUS_INITIALIZE
+static void *l4cplus_initializer;
+
+static void
+cleanup_logging(void)
+{
+	log4cplus_deinitialize(l4cplus_initializer);
+}
+#endif
+
 int main(int argc, char **argv){
 	int c;
 	int colouron = 0;
@@ -804,6 +818,10 @@ int main(int argc, char **argv){
 
 	int delay=2;
 
+#ifdef HAVE_LOG4CPLUS_INITIALIZE
+	l4cplus_initializer = log4cplus_initialize();
+	atexit((void (*)(void))cleanup_logging);
+#endif
 	sg_log_init("saidar", "SAIDAR_LOG_PROPERTIES", argc ? argv[0] : NULL);
 	sg_init(1);
 	if(sg_drop_privileges() != 0){
@@ -915,5 +933,6 @@ int main(int argc, char **argv){
 
 	endwin();
 	sg_shutdown();
+
 	return 0;
 }
